﻿using KdanCommon.GoogleCloud.Data.Vision;
using KdanCommon.Helpers;
using Newtonsoft.Json;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Net.Http;
using System.Text;
using System.Threading;
using System.Threading.Tasks;
using Windows.Globalization;
using Windows.Storage;
using Windows.System;

namespace KdanCommon.GoogleCloud
{
    public class GoogleCloud
    {
        public static string VisionDomain = "https://cms.kdanmobile.com";
        private Uri _visionImagesUri = null;

        private HttpClient _httpClient = null;
        private string _key = null;

        public GoogleCloud(string key)
        {
            _key = key;
            _httpClient = new HttpClient();
            _visionImagesUri = new Uri($"{VisionDomain}/v1/images:annotate");
        }

        ~GoogleCloud()
        {
            _httpClient.Dispose();
        }

        private async Task<ImagesResponse> GetVisionImages(List<StorageFile> images)
        {
            ImagesResponse response = null;
            var base64Contents = new List<string>();
            foreach (var image in images)
            {
                // 最多16張圖
                var base64Content = await Base64Helper.StorageFileToBase64(image);
                base64Contents.Add(base64Content);
            }
            var imagesRequest = new ImgesRequest(base64Contents);
            string requestJsonStr = JsonConvert.SerializeObject(imagesRequest);
            var content = new StringContent(requestJsonStr, System.Text.Encoding.UTF8, "application/json");
            var result = await _httpClient.PostAsync(_visionImagesUri, content);
            if (result.StatusCode == System.Net.HttpStatusCode.OK)
            {
                var jsonString = await result.Content.ReadAsStringAsync();
                response = JsonTool.DeserializeJSON<ImagesResponse>(jsonString);
            }
            return response;
        }
    }
}
